==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Input/cdaudio/translations/cdaudio_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="39"/>
        <source>CD Audio Plugin</source>
        <translation>Módulo de audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="86"/>
        <source>About CD Audio Plugin</source>
        <translation>Acerca del módulo de audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="87"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Módulo de audio CD para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Compilado con libcdio-%1 y libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="91"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Uso: abrir cdda:// con el diálogo Añadir URL o la línea de comandos</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Configuración del módulo de audio CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Sobreescribir dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Límite de velocidad del CD:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Usar CD-Text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>CDDB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Usar HTTP en lugar de CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Ruta:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Limpiar la cache CDDB</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Input/cdaudio/translations/cdaudio_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>CDAudioSettingsDialog</name>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Configuración del módulo de audio CD</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="139"/>
        <source>Override device:</source>
        <translation>Sobreescribir dispositivo:</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="129"/>
        <source>Limit cd speed:</source>
        <translation>Límite de velocidad del CD:</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="122"/>
        <source>Use cd-text</source>
        <translation>Usar CD-Text</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="39"/>
        <source>CDDB</source>
        <translation>CDDB</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="48"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Usar HTTP en lugar de CDDBP</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="58"/>
        <source>Server:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="65"/>
        <source>Path:</source>
        <translation>Ruta:</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="75"/>
        <source>Port:</source>
        <translation>Puerto:</translation>
    </message>
    <message>
        <location filename="../cdaudiosettingsdialog.ui" line="87"/>
        <source>Clear CDDB cache</source>
        <translation>Limpiar la cache CDDB</translation>
    </message>
</context>
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="52"/>
        <source>CD Audio Plugin</source>
        <translation>Módulo de audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="98"/>
        <source>About CD Audio Plugin</source>
        <translation>Acerca del módulo de audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="99"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Módulo de audio CD para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="101"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Compilado con libcdio-%1 y libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="104"/>
        <source>Compiled against libcdio-%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="107"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="108"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Uso: abrir cdda:// con el diálogo Añadir URL o la línea de comandos</translation>
    </message>
</context>
</TS>
